@@ -1,57 +1,54 @@
 # flake8: noqa
-from graphql import ResolveInfo
+from graphql import GraphQLResolveInfo as ResolveInfo
 
-from .objecttype import ObjectType
-from .interface import Interface
-from .mutation import Mutation
-from .scalars import Scalar, String, ID, Int, Float, Boolean
+from .argument import Argument
+from .base64 import Base64
+from .context import Context
 from .datetime import Date, DateTime, Time
 from .decimal import Decimal
-from .json import JSONString
-from .uuid import UUID
-from .schema import Schema
-from .structures import List, NonNull
+from .dynamic import Dynamic
 from .enum import Enum
 from .field import Field
 from .inputfield import InputField
-from .argument import Argument
 from .inputobjecttype import InputObjectType
-from .dynamic import Dynamic
+from .interface import Interface
+from .json import JSONString
+from .mutation import Mutation
+from .objecttype import ObjectType
+from .scalars import ID, BigInt, Boolean, Float, Int, Scalar, String
+from .schema import Schema
+from .structures import List, NonNull
 from .union import Union
-from .context import Context
-
-# Deprecated
-from .abstracttype import AbstractType
-
+from .uuid import UUID
 
 __all__ = [
-    "ObjectType",
-    "InputObjectType",
-    "Interface",
-    "Mutation",
-    "Enum",
-    "Field",
-    "InputField",
-    "Schema",
-    "Scalar",
-    "String",
-    "ID",
-    "Int",
-    "Float",
+    "Argument",
+    "Base64",
+    "BigInt",
+    "Boolean",
+    "Context",
     "Date",
     "DateTime",
-    "Time",
     "Decimal",
-    "JSONString",
-    "UUID",
-    "Boolean",
-    "List",
-    "NonNull",
-    "Argument",
     "Dynamic",
-    "Union",
-    "Context",
+    "Enum",
+    "Field",
+    "Float",
+    "ID",
+    "InputField",
+    "InputObjectType",
+    "Int",
+    "Interface",
+    "JSONString",
+    "List",
+    "Mutation",
+    "NonNull",
+    "ObjectType",
     "ResolveInfo",
-    # Deprecated
-    "AbstractType",
+    "Scalar",
+    "Schema",
+    "String",
+    "Time",
+    "UUID",
+    "Union",
 ]
